svn commit: r12605 - trunk/src/model-mdr/src/org/argouml/model/mdr/XmiHeaderProviderImpl.java

[email protected]
Newsgroups gmane.comp.lang.uml.argouml.cvs
Message-ID <[email protected]>
Author: linus
Date: 2007-05-11 23:08:08-0700
New Revision: 12605

Modified:
   trunk/src/model-mdr/src/org/argouml/model/mdr/XmiHeaderProviderImpl.java

Log:
Style issues.

Modified: trunk/src/model-mdr/src/org/argouml/model/mdr/XmiHeaderProviderImpl.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/model-mdr/src/org/argouml/model/mdr/XmiHeaderProviderImpl.java?view=diff&rev=12605&p1=trunk/src/model-mdr/src/org/argouml/model/mdr/XmiHeaderProviderImpl.java&p2=trunk/src/model-mdr/src/org/argouml/model/mdr/XmiHeaderProviderImpl.java&r1=12604&r2=12605
==============================================================================
--- trunk/src/model-mdr/src/org/argouml/model/mdr/XmiHeaderProviderImpl.java	(original)
+++ trunk/src/model-mdr/src/org/argouml/model/mdr/XmiHeaderProviderImpl.java	2007-05-11 23:08:08-0700
@@ -44,10 +44,10 @@
     
     /**
      * Constructor.
      * @param version the version of ArgoUML that saved the XMI
      */
-    public XmiHeaderProviderImpl(String version) {
-        this.version = version;
+    public XmiHeaderProviderImpl(String ver) {
+        version = ver;
     }
 
     /*
@@ -62,7 +62,8 @@
                     + " version " + WriterBase.EXPORTER_VERSION 
                     + ")</XMI.exporter>\n"
             + "      <XMI.exporterVersion>" + version
-                    + " revised on $Date$ "
+                    + " revised on "
+                    + "$Date$ "
                     + "</XMI.exporterVersion>\n"
             + "    </XMI.documentation>\n"
             + "    <XMI.metamodel xmi.name=\"UML\" xmi.version=\""
@@ -44,10 +44,10 @@
     /**
      * Constructor.
-     * @param version the version of ArgoUML that saved the XMI
+     * @param ver the version of ArgoUML that saved the XMI
      */
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.